==> haskell-charset-0.3.12-88.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-AmjtFvhjrx2JD02c7IN6qm
key:                  charset-0.3.12-AmjtFvhjrx2JD02c7IN6qm
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  5a43b5819ffd6aedd0a38950e41026d6
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-AmjtFvhjrx2JD02c7IN6qm
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.12-89-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-2D9nY7DBdxY1nhEyRK58pN
key:                  charset-0.3.12-2D9nY7DBdxY1nhEyRK58pN
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  84ac03cfbaae0fdd67fcfe7fbd059028
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-2D9nY7DBdxY1nhEyRK58pN
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
